# Changelog

## 2.3.1 (2023-03-31)

#### Fixes

* fix commit_all not adding untracked files in /dist
#### Others

* build v2.3.0


## v2.3.0 (2023-03-31)

#### New Features

* add -up/--update switch to hassle cli
#### Fixes

* add missing letter in commit_all git command
* fix pip install command arguments
#### Refactorings

* remove uneccessary git command in commit_all block
#### Others

* build v2.3.0
* update changelog
* update readme


## v2.2.0 (2023-03-22)

#### New Features

* make dependency versions optional
* add alt structure for non-package projects
#### Others

* build v2.2.0
* update changelog


## v2.0.2 (2023-02-20)

#### Fixes

* add 'pip install -e .' cmd
* add missing '>=' to min py version in template
#### Others

* build v2.0.2
* update changelog


## v2.0.1 (2023-02-18)

#### Fixes

* change load_template to load_config
* fix project.urls in pyproject template
#### Others

* build v2.0.1
* update changelog


## v2.0.0 (2023-02-18)

#### Others

* build v2.0.0